<?php
/**
 * Functions  Template
 *
 * @package threadz
 */

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 */
include_once (get_template_directory() . '/include/theme-options.php');

function threadz_setup() {
	global $content_width;
        // Global content width.
	if ( !isset($content_width) )
		$content_width = 740;

	// Add default posts and comments RSS feed links to <head>.
	add_theme_support( 'automatic-feed-links' );

	//	For translation/localization support.
	load_theme_textdomain( 'threadz', get_template_directory() .'/languages' );

	// Add callback for custom TinyMCE editor stylesheets. (editor-style.css)
	add_editor_style();
      
        // add tag support to pages
        register_taxonomy_for_object_type('post_tag', 'page');

        // add post-formats to post_type 'page'
        add_theme_support( 'post-formats', array( 'aside', 'status' ) );

	// thumbnail size set for view posts
	add_theme_support( 'post-thumbnails' );

	// Add support for custom backgrounds.
	add_theme_support( 'custom-background', array( 'default-color' => 'f6f6f6',) );

	add_theme_support( 'custom-header', array (
	   'default-image' => '',	
	   'height'	   => 132,
	   'width'         => 500, 
           'header-text'   => false,
	));   
 
       // This theme uses wp_nav_menu() in Header only.
        register_nav_menu('header-menu', __( 'Header Menu', 'threadz' ));

}
add_action( 'after_setup_theme', 'threadz_setup' );

        /**
         *  JavaScripts and css to generated page.
         */
	function threadz_add_theme_scripts() {
	    wp_enqueue_style( 'style', get_stylesheet_uri() );
            wp_enqueue_script( 'dropdown', get_template_directory_uri() . '/js/dropdown.js', array( 'jquery' ), '1.0.0' );
            wp_enqueue_script( 'shadowbox', get_template_directory_uri() . '/js/shadowbox.js', array( 'jquery' ), '3.0.3' );
	// Comment reply function
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	    }
        }
        add_action( 'wp_enqueue_scripts', 'threadz_add_theme_scripts' );

    /**
     *  Shadowbox image handler only works on single posts pages
     */
add_action('wp_head', 'threadz_shadowbox_script');
    function threadz_shadowbox_script() {
        echo '<script type="text/javascript"> Shadowbox.init({
        displayNav:    "true"
        }); </script>';
    }
    
    /**
     *  reformat the more link for excerpts 
     */
    function threadz_excerpt_more($more) {
        global $post;
           return  
	       '<a class="moretag" href="'. get_permalink($post->ID) . '">' . __( 'Читать далее...', 'threadz' ) . '</a>';
    }
    add_filter('excerpt_more', 'threadz_excerpt_more');

    
/**
 * Register sidebars and widgetized areas.
 *
 */
function threadz_widgets_init() {

register_sidebar( array(
'name' => __( 'Main Sidebar', 'threadz' ),
'description' => __( 'Main sidebar on Right Side of Theme', 'threadz' ),
'id' => 'main-sidebar',
'before_widget' => '<div id="%1$s" class="sidebar-right %2$s">',
'after_widget' => '</div> <!-- end widget sidebar -->',
'before_title' => '<h2 class="widget-title">',
'after_title' => '</h2>',
));

register_sidebar( array(
'name' => __( 'Footer One', 'threadz' ),
'description' => __( 'First box in footer', 'threadz' ),
'id' => 'footer-one',
'before_widget' => '<div id="%1$s" class="widget-footer %2$s">',
'after_widget' => '</div> <!-- end widget-footer -->',
'before_title' => '<h2 class="widget-title">',
'after_title' => '</h2>',
));

register_sidebar( array(
'name' => __( 'Footer Two', 'threadz' ),
'description' => __( 'Second box in footer', 'threadz' ),
'id' => 'footer-two',
'before_widget' => '<div id="%1$s" class="widget-footer %2$s">',
'after_widget' => '</div> <!-- end widget-footer -->',
'before_title' => '<h2 class="widget-title">',
'after_title' => '</h2>',
));

register_sidebar( array(
'name' => __( 'Footer Three', 'threadz' ),
'description' => __( 'Third box in footer', 'threadz' ),
'id' => 'footer-three',
'before_widget' => '<div id="%1$s" class="widget-footer %2$s">',
'after_widget' => '</div> <!-- end widget-footer -->',
'before_title' => '<h2 class="widget-title">',
'after_title' => '</h2>',
));
}
add_action('widgets_init', 'threadz_widgets_init' );

// insert footer credits hook
function threadz_footer_credits() {
    echo '<p><a href="https://wphost.me/mancgi/partnerprogram?partner=24&amp;project=1"> <small>Wordpress хостинг</small></a></p>';
}
add_action( 'threadz_footer_credits', 'threadz_footer_credits' );

// add social links to users contact page
function threadz_new_contactmethods( $contactmethods ) {
    // Add Twitter
    $contactmethods['twitter'] = 'Twitter';
    //add Facebook
    $contactmethods['facebook'] = 'Facebook';
    //add LinkedIn
    $contactmethods['linkedin'] = 'LinkedIn';
    //add GPlus
    $contactmethods['gplus'] = 'GooglePlus';

        return $contactmethods;
}
add_filter('threadz_user_contactmethods','threadz_new_contactmethods',10,1);



?>